@@ -1,5 +1,5 @@
 import os
-from copy import deepcopy
+from copy import copy
 from functools import partial
 from absql.utils import get_function_arg_names
 from gusty.parsing.loaders import generate_loader
@@ -16,7 +16,13 @@ default_parsers = {
 }
 
 
-def parse(file_path, parse_dict=default_parsers, loader=None, runner=None):
+def parse(
+    file_path,
+    parse_dict=default_parsers,
+    loader=None,
+    runner=None,
+    render_on_create=False,
+):
     """
     Reading in yaml specs / frontmatter.
     """
@@ -31,6 +37,8 @@ def parse(file_path, parse_dict=default_parsers, loader=None, runner=None):
         parser = partial(parser, loader=loader)
     if "runner" in get_function_arg_names(parser):
         parser = partial(parser, runner=runner)
+    if "render_on_create" in get_function_arg_names(parser):
+        parser = partial(parser, render_on_create=render_on_create)
 
     yaml_file = parser(file_path)
 
@@ -47,7 +55,7 @@ def parse(file_path, parse_dict=default_parsers, loader=None, runner=None):
     yaml_file["file_path"] = file_path
 
     # gusty will also attach the absql_runner
-    yaml_file["absql_runner"] = deepcopy(runner)
+    yaml_file["absql_runner"] = copy(runner)
 
     # Check dependencies
     if "dependencies" in yaml_file.keys():
