@@ -50,14 +50,10 @@ def parse_py(file_path, loader=None, runner=None, render_on_create=False):
 
         # search for a python callable if one is specified
         if "python_callable" in job_spec.keys():
-            callable = job_spec["python_callable"]
-            if isinstance(callable, str):
-                job_spec.update(
-                    {"python_callable": get_callable_from_file(file_path, callable)}
-                )
-            else:
-                job_spec.update({"python_callable": callable})
-
+            callable_name = job_spec["python_callable"]
+            job_spec.update(
+                {"python_callable": get_callable_from_file(file_path, callable_name)}
+            )
         # Default to sourcing this file for a PythonOperator
         else:
             job_spec.update({"python_callable": lambda: exec(open(file_path).read())})
