@@ -12,7 +12,7 @@ def test_get_operator_parameters():
         def execute(self, context):
             print(self.a)
 
-    params = _get_operator_parameters(ACustomOperator)
+    params = _get_operator_parameters(ACustomOperator, {})
 
     assert "a" in params
     assert list(params) == ["self", "a", "kwargs"]
@@ -22,7 +22,7 @@ def test_get_operator_parameters_attribute():
     f = lambda a, **kwargs: BaseOperator(**kwargs)
     f._gusty_parameters = ("a",)
 
-    params = _get_operator_parameters(f)
+    params = _get_operator_parameters(f, {})
 
     assert "a" in params
     assert list(params) == ["a"]
